@@ -12,7 +12,7 @@ from typing import Dict, Callable, Any
 
 if typing.TYPE_CHECKING:
     from .poll import PollData
-    from .pubsub import PubSubData, PubSubPointRedemption, PubSubBits, PubSubModerationAction, PubSubSubscription
+    from .pubsub import PubSubData, PubSubPointRedemption, PubSubBits, PubSubModerationAction, PubSubSubscription, PubSubPollData, PubSubFollow
 
 from .channel import Channel
 from .command import Command
@@ -220,6 +220,12 @@ class Mod:
         :param data: data specific to the moderation action taken
         """
 
+    async def on_pubsub_twitch_poll_update(self, raw: 'PubSubData', poll: 'PubSubPollData'):
+        """
+        triggered when a poll is start/updated/completed on a channel
+        :param poll: the poll that the triggered the event
+        """
+
     async def on_pubsub_subscription(self, raw: 'PubSubData', data: 'PubSubSubscription'):
         """
         triggered when a user subscribes or resubscribes to a channel
@@ -227,11 +233,24 @@ class Mod:
         :param data: data specific to the user subscription
         """
 
+    async def on_pubsub_user_follow(self, raw: 'PubSubData', data: 'PubSubFollow'):
+        """
+        triggered when a user follows a channel that is listened to by the bot's pubsub client
+        :param raw: the raw pubsub message
+        :param data: data specific to the user follow
+        """
+
     async def on_bot_shutdown(self):
         """
         triggered when the bot is shutdown
         """
 
+    async def on_after_database_init(self):
+        """
+        triggered AFTER the bot creates all defined tables in the database
+        this event should be used when you need to do database operations as soon as possible on bot startup
+        """
+
     # endregion
 
 
